+++
title = "Force line break"
tags = ["body", "force", "line-break"]
draft = false
+++

From [`C-h i g (org) Paragraphs`](https://orgmode.org/manual/Paragraphs.html):

> Paragraphs are separated by at least one empty line.  If you need to
> enforce a line break within a paragraph, use ‘\\\\’ at the end of a line.

Line 1 <br />
Line 2
